pub struct EntityMetadataCollection {
pub total_count: Option<Option<i64>>,
pub next_cursor: Option<Option<String>>,
pub items: Vec<EntityMetadataItem>,
}Expand description
EntityMetadataCollection : Entity metadata collection.
Fields
total_count: Option<Option<i64>>Total number of items in underlying collection, fragment of which is available in items collection.
next_cursor: Option<Option<String>>If specified, contains a cursor to query next page of the items collection.
items: Vec<EntityMetadataItem>Implementations
Sourceimpl EntityMetadataCollection
impl EntityMetadataCollection
Sourcepub fn new(items: Vec<EntityMetadataItem>) -> EntityMetadataCollection
pub fn new(items: Vec<EntityMetadataItem>) -> EntityMetadataCollection
Entity metadata collection.