pub struct PackageCodeCollection {
pub total_count: Option<Option<i64>>,
pub next_cursor: Option<Option<String>>,
pub items: Vec<PackageCodeCollectionItem>,
}Expand description
PackageCodeCollection : Package code collection.
Fields
total_count: Option<Option<i64>>Total number of items in underlying collection, fragment of which is available in items collection.
next_cursor: Option<Option<String>>If specified, contains a cursor to query next page of the items collection.
items: Vec<PackageCodeCollectionItem>Implementations
Sourceimpl PackageCodeCollection
impl PackageCodeCollection
Sourcepub fn new(items: Vec<PackageCodeCollectionItem>) -> PackageCodeCollection
pub fn new(items: Vec<PackageCodeCollectionItem>) -> PackageCodeCollection
Package code collection.