pub struct ProgrammaticScryptoSborValueBytes {
pub kind: ProgrammaticScryptoSborValueKind,
pub type_name: Option<Option<String>>,
pub field_name: Option<Option<String>>,
pub element_kind: ProgrammaticScryptoSborValueKind,
pub element_type_name: Option<String>,
pub hex: String,
}Fields
kind: ProgrammaticScryptoSborValueKindtype_name: Option<Option<String>>The name of the type of this value. This is only output when a schema is present and the type has a name. This property is ignored when the value is used as an input to the API.
field_name: Option<Option<String>>The name of the field which hosts this value. This property is only included if this value is a child of a Tuple or Enum with named fields. This property is ignored when the value is used as an input to the API.
element_kind: ProgrammaticScryptoSborValueKindelement_type_name: Option<String>hex: StringHex-encoded binary blob.
Implementations
Sourceimpl ProgrammaticScryptoSborValueBytes
impl ProgrammaticScryptoSborValueBytes
pub fn new( kind: ProgrammaticScryptoSborValueKind, element_kind: ProgrammaticScryptoSborValueKind, hex: String, ) -> ProgrammaticScryptoSborValueBytes