pub struct ProgrammaticScryptoSborValueMap {
pub kind: ProgrammaticScryptoSborValueKind,
pub type_name: Option<Option<String>>,
pub field_name: Option<Option<String>>,
pub key_kind: ProgrammaticScryptoSborValueKind,
pub key_type_name: Option<String>,
pub value_kind: ProgrammaticScryptoSborValueKind,
pub value_type_name: Option<String>,
pub entries: Vec<ProgrammaticScryptoSborValueMapEntry>,
}Fields
kind: ProgrammaticScryptoSborValueKindtype_name: Option<Option<String>>The name of the type of this value. This is only output when a schema is present and the type has a name. This property is ignored when the value is used as an input to the API.
field_name: Option<Option<String>>The name of the field which hosts this value. This property is only included if this value is a child of a Tuple or Enum with named fields. This property is ignored when the value is used as an input to the API.
key_kind: ProgrammaticScryptoSborValueKindkey_type_name: Option<String>value_kind: ProgrammaticScryptoSborValueKindvalue_type_name: Option<String>entries: Vec<ProgrammaticScryptoSborValueMapEntry>Implementations
Sourceimpl ProgrammaticScryptoSborValueMap
impl ProgrammaticScryptoSborValueMap
pub fn new( kind: ProgrammaticScryptoSborValueKind, key_kind: ProgrammaticScryptoSborValueKind, value_kind: ProgrammaticScryptoSborValueKind, entries: Vec<ProgrammaticScryptoSborValueMapEntry>, ) -> ProgrammaticScryptoSborValueMap