pub struct StatePackageCodePageResponse {
pub ledger_state: Box<LedgerState>,
pub total_count: Option<Option<i64>>,
pub next_cursor: Option<Option<String>>,
pub items: Vec<PackageCodeCollectionItem>,
pub package_address: String,
}Fields
ledger_state: Box<LedgerState>total_count: Option<Option<i64>>Total number of items in underlying collection, fragment of which is available in items collection.
next_cursor: Option<Option<String>>If specified, contains a cursor to query next page of the items collection.
items: Vec<PackageCodeCollectionItem>package_address: StringBech32m-encoded human readable version of the address.
Implementations
Sourceimpl StatePackageCodePageResponse
impl StatePackageCodePageResponse
pub fn new( ledger_state: LedgerState, items: Vec<PackageCodeCollectionItem>, package_address: String, ) -> StatePackageCodePageResponse